Size

Struct Size 

pub struct Size<Num = f64> { /* private fields */ }
Generic size type. Size is not guaranteed to be non-negative.

Implementations

Source

impl<Num: Num + Copy> Size<Num>

pub fn new(width: Num, height: Num) -> Self

Creates a new instance.

pub fn width(&self) -> Num

Width.

pub fn half_width(&self) -> Num

Half width.

pub fn height(&self) -> Num

Height.

pub fn half_height(&self) -> Num

Half height.

pub fn is_zero(&self) -> bool

Returns true if both width and height are exactly zero.

pub fn cast<T>(&self) -> Size<T>
where Num: ToPrimitive, T: NumCast,

Casts the underlying width and height values into the requested type.

pub fn to_rect(&self) -> Rect<Num>

Converts size object to a rectangle with left-top point (0, 0).