pub enum Geom<P> {
Point(P),
MultiPoint(MultiPoint<P>),
Contour(Contour<P>),
MultiContour(MultiContour<P>),
Polygon(Polygon<P>),
MultiPolygon(MultiPolygon<P>),
}Expand description
Enum of different geometry types. This enum implements the Geometry trait so you can use any generic geometry
method without knowing a specific geometry type you are working with.
Variants
Point(P)
Point geometry.
MultiPoint(MultiPoint<P>)
MultiPoint geometry.
Contour(Contour<P>)
Contour geometry.
MultiContour(MultiContour<P>)
MultiContour geometry.
Polygon(Polygon<P>)
Polygon geometry.
MultiPolygon(MultiPolygon<P>)
MultiPolygon geometry.