pub struct Contour<Point> { /* private fields */ }Expand description
Simple crate::Contour implementation.
Implementations
Sourceimpl<Point> Contour<Point>
impl<Point> Contour<Point>
Sourcepub fn into_closed(self) -> Option<ClosedContour<Point>>
pub fn into_closed(self) -> Option<ClosedContour<Point>>
Converts self into a ClosedContour instance if the contour is closed, or returns None if the contour is
open.
Sourcepub fn project_points<P, Proj>(&self, projection: &Proj) -> Option<Contour<P>>where
Proj: Projection<InPoint = Point, OutPoint = P> + ?Sized,
pub fn project_points<P, Proj>(&self, projection: &Proj) -> Option<Contour<P>>where
Proj: Projection<InPoint = Point, OutPoint = P> + ?Sized,
Projects all the points of the contour with the given projection.