Rect

Struct Rect 

pub struct Rect<N = f64> { /* private fields */ }
Rectangle in 2d cartesian coordinate space.

Implementations

Source

impl<N> Rect<N>

pub fn new(x_min: N, y_min: N, x_max: N, y_max: N) -> Self

Creates a new rectangle.

pub fn x_min(&self) -> N

X min.

pub fn x_max(&self) -> N

X max.

pub fn y_min(&self) -> N

Y min.

pub fn y_max(&self) -> N

Y max.

pub fn width(&self) -> N

Width of the rectangle. Guaranteed to be non-negative.

pub fn height(&self) -> N

Height of the rectangle. Guaranteed to be non-negative.

pub fn half_width(&self) -> N

Half of the width of the rectangle. Guaranteed to be non-negative.

pub fn half_height(&self) -> N

Half of the height of the rectangle. Guaranteed to be non-negative.

pub fn into_contour(self) -> ClosedContour<Point2<N>>

Converts the rectangle into a closed contour of points.

pub fn shrink(&self, amount: N) -> Self

Moves the boundaries of the rectangle by amount inside (outside, if the amount is negative). If the width or height of the resulting rectangle are negative, they are set to 0.

pub fn shift(&self, dx: N, dy: N) -> Self

Adds the given amount to the coordinates of the rectangle.

pub fn merge(&self, other: Self) -> Self

Creates a new rectangle with the boundaries of this and other one.

pub fn from_point(p: &impl CartesianPoint2d<Num = N>) -> Self

Creates a zero-area rectangle from the point.

pub fn from_points<'a, P: CartesianPoint2d<Num = N> + 'a>( points: impl IntoIterator<Item = P>, ) -> Option<Self>

Returns a minimum rectangle that contains all the points in the iterator.

Returns None if the iterator is empty.

pub fn contains(&self, point: &impl CartesianPoint2d<Num = N>) -> bool

Returns true if the point is inside (or on a side) of the rectagle.

pub fn magnify(&self, factor: N) -> Self

Changes the width and height of the rectangle by the factor of factor, keeping the center of the rectangle at the same place.

pub fn limit(&self, other: Self) -> Self

Returns a new rectangle, boundaries of which are inside of boundaries of this and the other rectangles.

pub fn center(&self) -> Point2<N>

Returns the center point of the rectangle.

pub fn into_quadrangle(self) -> [Point2<N>; 4]

Returns a set of 4 points - corners of the rectangle.

The order of points is:

  1. Left bottom
  2. Left top
  3. Right top
  4. Right bottom
pub fn intersects(&self, other: Rect<N>) -> bool

Returns true if two rectangle have at least one common point.