pub struct Segment<Point>(pub Point, pub Point);Expand description
A strait line segment between two points.
Tuple Fields
0: Point1: PointImplementations
Sourceimpl<P: CartesianPoint2d> Segment<P>
impl<P: CartesianPoint2d> Segment<P>
Sourcepub fn distance_to_point_sq<Point: CartesianPoint2d<Num = P::Num>>(
&self,
point: &Point,
) -> P::Num
pub fn distance_to_point_sq<Point: CartesianPoint2d<Num = P::Num>>( &self, point: &Point, ) -> P::Num
Shortest euclidean distance (squared) between a point and the segment:
- if the normal from the point to the segment ends inside the segment, the returned value is the squared length of the normal
- if the normal from the point to the segment ends outside of the segment, the returned value is the smaller one of the distances between the point and the segment’s endpoints
Sourcepub fn intersects<Point: CartesianPoint2d<Num = P::Num>>(
&self,
other: &Segment<Point>,
) -> bool
pub fn intersects<Point: CartesianPoint2d<Num = P::Num>>( &self, other: &Segment<Point>, ) -> bool
Returns true, if the segment has at least one common point with the other segment.